==> ejc-lz-impl-3.0.0-20220526.021003-106-sources.jar: com/ejianc/business/base/bean/CustomermanageEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 客户管理信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_customer_managearchives")
public class CustomermanageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 客户编码
    @TableField(value="name")
    private String name; // 客户名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="info_id")
    private Long infoId; // 客户基本信息id
    @TableField(value="abbname")
    private String abbname; // 客户简称
    @TableField(value="license_code")
    private String licenseCode; // 营业执照号
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="credit_range")
    private String creditRange; // 信用范围
    @TableField(value="credit_level")
    private String creditLevel; // 信用级别
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="sales_quota")
    private String salesQuota; // 销售额度
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="corporate_id_number")
    private String corporateIdNumber; // 法人身份证号
    @TableField(value="corporate_phone")
    private String corporatePhone; // 法人手机号
    @TableField(value="registered_capital")
    private String registeredCapital; // 注册资金
    @TableField(value="category_name")
    private String categoryName; // 客户分类名称
    @TableField(value="category_id")
    private Long categoryId; // 客户分类id
    @TableField(value="org_certificate_code")
    private String orgCertificateCode; // 组织机构证号
    @TableField(value="security_level")
    private Integer securityLevel; // 安全级别:1 一级 2 二级 3 三级
    @TableField(value="hide_flag")
    private Integer hideFlag; // 隐藏标志: 0 显示 1 不显示
    @TableField(value="linker_name")
    private String linkerName; // 联系人名称
    @TableField(value="linker_phone")
    private String linkerPhone; // 联系人电话
    @TableField(value="bank_name")
    private String bankName; // 银行名称
    @TableField(value="bank_account")
    private String bankAccount; // 银行账户
    @TableField(value="bank_person")
    private String bankPerson; // 银行开户名
    @TableField(value="control_name")
    private String controlName; // 实际控制人名称
    @TableField(value="control_phone")
    private String controlPhone; // 控制人名称
    


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getInfoId() {
        return infoId;
    }

    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    public String getAbbname() {
        return abbname;
    }

    public void setAbbname(String abbname) {
        this.abbname = abbname;
    }
    public String getLicenseCode() {
        return licenseCode;
    }

    public void setLicenseCode(String licenseCode) {
        this.licenseCode = licenseCode;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getCreditRange() {
        return creditRange;
    }

    public void setCreditRange(String creditRange) {
        this.creditRange = creditRange;
    }
    public String getCreditLevel() {
        return creditLevel;
    }

    public void setCreditLevel(String creditLevel) {
        this.creditLevel = creditLevel;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public String getSalesQuota() {
        return salesQuota;
    }

    public void setSalesQuota(String salesQuota) {
        this.salesQuota = salesQuota;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public String getCorporateIdNumber() {
        return corporateIdNumber;
    }

    public void setCorporateIdNumber(String corporateIdNumber) {
        this.corporateIdNumber = corporateIdNumber;
    }

    public String getCorporatePhone() {
        return corporatePhone;
    }

    public void setCorporatePhone(String corporatePhone) {
        this.corporatePhone = corporatePhone;
    }

    public String getRegisteredCapital() {
        return registeredCapital;
    }

    public void setRegisteredCapital(String registeredCapital) {
        this.registeredCapital = registeredCapital;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getOrgCertificateCode() {
        return orgCertificateCode;
    }

    public void setOrgCertificateCode(String orgCertificateCode) {
        this.orgCertificateCode = orgCertificateCode;
    }

    public Integer getSecurityLevel() {
        return securityLevel;
    }

    public void setSecurityLevel(Integer securityLevel) {
        this.securityLevel = securityLevel;
    }

    public Integer getHideFlag() {
        return hideFlag;
    }

    public void setHideFlag(Integer hideFlag) {
        this.hideFlag = hideFlag;
    }


    public String getLinkerName() {
        return linkerName;
    }

    public void setLinkerName(String linkerName) {
        this.linkerName = linkerName;
    }

    public String getLinkerPhone() {
        return linkerPhone;
    }

    public void setLinkerPhone(String linkerPhone) {
        this.linkerPhone = linkerPhone;
    }

    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public String getBankPerson() {
        return bankPerson;
    }

    public void setBankPerson(String bankPerson) {
        this.bankPerson = bankPerson;
    }

    public String getControlName() {
        return controlName;
    }

    public void setControlName(String controlName) {
        this.controlName = controlName;
    }

    public String getControlPhone() {
        return controlPhone;
    }

    public void setControlPhone(String controlPhone) {
        this.controlPhone = controlPhone;
    }
}

==> ejc-lz-impl-3.0.0-20220830.080126-153-sources.jar: com/ejianc/business/base/bean/CustomermanageEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 客户管理信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_customer_managearchives")
public class CustomermanageEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="code")
    private String code; // 客户编码
    @TableField(value="name")
    private String name; // 客户名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="info_id")
    private Long infoId; // 客户基本信息id
    @TableField(value="abbname")
    private String abbname; // 客户简称
    @TableField(value="license_code")
    private String licenseCode; // 营业执照号
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="credit_range")
    private String creditRange; // 信用范围
    @TableField(value="credit_level")
    private String creditLevel; // 信用级别
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="sales_quota")
    private String salesQuota; // 销售额度
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="corporate_id_number")
    private String corporateIdNumber; // 法人身份证号
    @TableField(value="corporate_phone")
    private String corporatePhone; // 法人手机号
    @TableField(value="registered_capital")
    private String registeredCapital; // 注册资金
    @TableField(value="category_name")
    private String categoryName; // 客户分类名称
    @TableField(value="category_id")
    private Long categoryId; // 客户分类id
    @TableField(value="org_certificate_code")
    private String orgCertificateCode; // 组织机构证号
    @TableField(value="security_level")
    private Integer securityLevel; // 安全级别:1 一级 2 二级 3 三级
    @TableField(value="hide_flag")
    private Integer hideFlag; // 隐藏标志: 0 显示 1 不显示
    @TableField(value="linker_name")
    private String linkerName; // 联系人名称
    @TableField(value="linker_phone")
    private String linkerPhone; // 联系人电话
    @TableField(value="bank_name")
    private String bankName; // 银行名称
    @TableField(value="bank_account")
    private String bankAccount; // 银行账户
    @TableField(value="bank_person")
    private String bankPerson; // 银行开户名
    @TableField(value="control_name")
    private String controlName; // 实际控制人名称
    @TableField(value="control_phone")
    private String controlPhone; // 控制人名称
    @TableField(value="estiblish_time")
    private String estiblishTime; // 成立日期
    @TableField(value="reg_status	")
    private String regStatus; // 企业状态
    @TableField(value="credit_code")
    private String creditCode; // 社会统一信用代码
    @TableField(value="tax_number")
    private String taxNumber; // 纳税人识别号
    @TableField(value="company_org_type")
    private String companyOrgType; // 公司类型
    @TableField(value="to_time")
    private String toTime; // 经营结束时间
    @TableField(value="from_time")
    private String fromTime; // 经营开始时间
    @TableField(value="industry")
    private String industry; // 行业
    @TableField(value="approved_time")
    private String approvedTime; // 核准时间
    @TableField(value="actual_capital")
    private String actualCapital; // 失手注册资金
    @TableField(value="staff_num_range")
    private String staffNumRange; // 参保人数
    @TableField(value="social_staff_num")
    private Integer socialStaffNum; // 人员规模
    @TableField(value="reg_institute")
    private String regInstitute; // 登记机关
    @TableField(value="history_names")
    private String historyNames; // 曾用名
    @TableField(value="property3")
    private String property3; // 英文名
    @TableField(value="business_scope")
    private String businessScope; // 经营范围
    @TableField(value="is_help")
    private Integer isHelp; // 是否替厂发货 0 否 1 是



    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getInfoId() {
        return infoId;
    }

    public void setInfoId(Long infoId) {
        this.infoId = infoId;
    }
    public String getAbbname() {
        return abbname;
    }

    public void setAbbname(String abbname) {
        this.abbname = abbname;
    }
    public String getLicenseCode() {
        return licenseCode;
    }

    public void setLicenseCode(String licenseCode) {
        this.licenseCode = licenseCode;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getCreditRange() {
        return creditRange;
    }

    public void setCreditRange(String creditRange) {
        this.creditRange = creditRange;
    }
    public String getCreditLevel() {
        return creditLevel;
    }

    public void setCreditLevel(String creditLevel) {
        this.creditLevel = creditLevel;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public String getSalesQuota() {
        return salesQuota;
    }

    public void setSalesQuota(String salesQuota) {
        this.salesQuota = salesQuota;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public String getCorporateIdNumber() {
        return corporateIdNumber;
    }

    public void setCorporateIdNumber(String corporateIdNumber) {
        this.corporateIdNumber = corporateIdNumber;
    }

    public String getCorporatePhone() {
        return corporatePhone;
    }

    public void setCorporatePhone(String corporatePhone) {
        this.corporatePhone = corporatePhone;
    }

    public String getRegisteredCapital() {
        return registeredCapital;
    }

    public void setRegisteredCapital(String registeredCapital) {
        this.registeredCapital = registeredCapital;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getOrgCertificateCode() {
        return orgCertificateCode;
    }

    public void setOrgCertificateCode(String orgCertificateCode) {
        this.orgCertificateCode = orgCertificateCode;
    }

    public Integer getSecurityLevel() {
        return securityLevel;
    }

    public void setSecurityLevel(Integer securityLevel) {
        this.securityLevel = securityLevel;
    }

    public Integer getHideFlag() {
        return hideFlag;
    }

    public void setHideFlag(Integer hideFlag) {
        this.hideFlag = hideFlag;
    }


    public String getLinkerName() {
        return linkerName;
    }

    public void setLinkerName(String linkerName) {
        this.linkerName = linkerName;
    }

    public String getLinkerPhone() {
        return linkerPhone;
    }

    public void setLinkerPhone(String linkerPhone) {
        this.linkerPhone = linkerPhone;
    }

    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public String getBankPerson() {
        return bankPerson;
    }

    public void setBankPerson(String bankPerson) {
        this.bankPerson = bankPerson;
    }

    public String getControlName() {
        return controlName;
    }

    public void setControlName(String controlName) {
        this.controlName = controlName;
    }

    public String getControlPhone() {
        return controlPhone;
    }

    public void setControlPhone(String controlPhone) {
        this.controlPhone = controlPhone;
    }

    public String getEstiblishTime() {
        return estiblishTime;
    }

    public void setEstiblishTime(String estiblishTime) {
        this.estiblishTime = estiblishTime;
    }

    public String getRegStatus() {
        return regStatus;
    }

    public void setRegStatus(String regStatus) {
        this.regStatus = regStatus;
    }

    public String getCreditCode() {
        return creditCode;
    }

    public void setCreditCode(String creditCode) {
        this.creditCode = creditCode;
    }

    public String getTaxNumber() {
        return taxNumber;
    }

    public void setTaxNumber(String taxNumber) {
        this.taxNumber = taxNumber;
    }

    public String getCompanyOrgType() {
        return companyOrgType;
    }

    public void setCompanyOrgType(String companyOrgType) {
        this.companyOrgType = companyOrgType;
    }

    public String getToTime() {
        return toTime;
    }

    public void setToTime(String toTime) {
        this.toTime = toTime;
    }

    public String getFromTime() {
        return fromTime;
    }

    public void setFromTime(String fromTime) {
        this.fromTime = fromTime;
    }

    public String getIndustry() {
        return industry;
    }

    public void setIndustry(String industry) {
        this.industry = industry;
    }

    public String getApprovedTime() {
        return approvedTime;
    }

    public void setApprovedTime(String approvedTime) {
        this.approvedTime = approvedTime;
    }

    public String getActualCapital() {
        return actualCapital;
    }

    public void setActualCapital(String actualCapital) {
        this.actualCapital = actualCapital;
    }

    public String getStaffNumRange() {
        return staffNumRange;
    }

    public void setStaffNumRange(String staffNumRange) {
        this.staffNumRange = staffNumRange;
    }

    public Integer getSocialStaffNum() {
        return socialStaffNum;
    }

    public void setSocialStaffNum(Integer socialStaffNum) {
        this.socialStaffNum = socialStaffNum;
    }

    public String getRegInstitute() {
        return regInstitute;
    }

    public void setRegInstitute(String regInstitute) {
        this.regInstitute = regInstitute;
    }

    public String getHistoryNames() {
        return historyNames;
    }

    public void setHistoryNames(String historyNames) {
        this.historyNames = historyNames;
    }

    public String getProperty3() {
        return property3;
    }

    public void setProperty3(String property3) {
        this.property3 = property3;
    }

    public String getBusinessScope() {
        return businessScope;
    }

    public void setBusinessScope(String businessScope) {
        this.businessScope = businessScope;
    }

    public Integer getIsHelp() {
        return isHelp;
    }

    public void setIsHelp(Integer isHelp) {
        this.isHelp = isHelp;
    }
}
